@@ -187,24 +187,82 @@ class Base(Controller):
         os.system(f'ls {loc} | wc -l')
 
     @ex(
-        help="Copies things from zshrc.txt to ~/.bashrc or ~/zshrc",
+        help="Appends defaults: from zshrc.txt to ~/.bashrc or ~/.zshrc or tmux conf",
         arguments = [
             (['shell'], {
-                "help" : "One of {sh, zsh}. Imports a DT version of zshrc into bashrc or zshrc.",
+                "help" : "One of {sh, zsh, tmux}. Imports a DT version of zshrc into bashrc or zshrc. or tmux .conf into ~/",
                 "action": "store"
             })
         ]
     )
     def load(self):
         zshrc = os.path.abspath(__file__).split('/')[:-2] + ['ext', 'zshrc.txt']
+        tmux = os.path.abspath(__file__).split('/')[:-2] + ['ext', 'tmux.conf']
+
         zshrc_path = os.path.join('/'.join(zshrc))
+        tmux_path = os.path.join('/'.join(tmux))
         if self.app.pargs.shell == 'sh':
             os.system(f'cat {zshrc_path} >> ~/.bashrc ')
         if self.app.pargs.shell == 'zsh':
             os.system(f'cat {zshrc_path} >> ~/.zshrc ')
+        if self.app.pargs.shell == 'tmux':
+            os.system(f'cat {tmux_path} >> ~/.tmux.conf ')
         else:
-            raise NotImplementedError("Try one of {sh, zsh}")
+            raise NotImplementedError("Try one of {sh, zsh, tmux}")
 
+    @ex(
+        help='Operations on CLI hist',
+        arguments=[
+            (['-s'],{
+                "help" : "To show the full command if too long to fit in terminal",
+                "action" : "store"
+            }),
+            (['-id'],{
+                # TODO: likely delete
+            "help" : "Which CLI snippet ID to run",
+            "action": "store"
+            }),
+            (['-n'],{
+                # TODO: probably better as mandatory
+                "help" : "Which lines from the selected history to show/save",
+                "action" : "store"
+            })
+        ]
+    )
+    def hist(self):
+        if not self.app.pargs.s:
+            from ..ext.hist import hist_tail
+            import pprint as pp
+            n_lines = int(self.app.pargs.n or 20)
+            pp.pprint(hist_tail(n_lines))
+        else: 
+            from ..ext.hist import hist_show
+            print(hist_show(self.app.pargs.n))
+
+    @ex(
+        help='Operations with snippets',
+        arguments=[
+            (['n'],{
+                "help" : "Which snippet to run/create. Using commas to seperate ids"
+                "e.g. `dt run 13,23`",
+                "action" : "store"
+            }),
+            (['-ssh'],{
+                "help" : "Whether the command (includes?)/is? an SSH command",
+                "action": "store"
+            }),
+            (['-c'],{
+                # TODO: probably better as mandatory
+                "help" : "Which lines from the selected history to show/save",
+                "action" : "store"
+            })
+            # TODO: what if non-default n lines has been pased to hist
+        ]
+    )
+    def run(self):
+        from ..ext.run import run_command
+        n_lines = [int(x) for x in str(self.app.pargs.n).split(',')]
+        run_command(n_lines)
 
     @ex(
         help='Operations on the SSH config',
@@ -247,7 +305,7 @@ class Base(Controller):
                 os.system(f'ssh {target}')
 
     @ex(
-        help='Viz for ',
+        help='Basic viz using streamlit for image comparisons',
         arguments = [
             (['images'], {
                 'help' : 'Location of target images',
@@ -288,6 +346,7 @@ class Base(Controller):
         ]
     )
     def config(self):
+        # TODO: setup Data-toolkit specific config
         from ..ext.config_cmd import config
         args = self.app.pargs
 
