@@ -12,6 +12,7 @@ term_wdith = os.get_terminal_size().columns
 pd.set_option('display.max_colwidth',term_wdith - 20)
 
 # TODO: treat 'cd' in a special way s.t. we can generate the absolute path wherever possible
+# TODO: treat 'cd' in a specical way so that it can keep track of location.
 FILTER_TERMS = ['ls','install','dt hist', 'git ', 'dt ', 'code',
                 'ipython','htop','git push','git pull','git stash',
                 'tmux', 'nvidia-smi', 'ping']
@@ -31,6 +32,12 @@ def dt_conv(l: str):
 def filter_term(term: tuple):
     # TODO: does not seem to work properly
     # Logic: all filter terms need to _not_ match
+    if 'cd' in term[0]:
+        if term[0].split(' ')[1][0] not in ['~','/']:
+            return False
+        else:
+            return True
+
     return all([ft not in term[0] for ft in FILTER_TERMS])
 
 def hist_tail(n_lines=20):
